<a name="aea.helpers.http_requests"></a>
# aea.helpers.http`_`requests

Wrapper over requests library.

<a name="aea.helpers.http_requests.add_default_timeout"></a>
#### add`_`default`_`timeout

```python
add_default_timeout(fn: Callable, timeout: float) -> Callable
```

Add default timeout for requests methods.

